package App::DuckPAN::Cmd::Env::Cmd::Help;
our $AUTHORITY = 'cpan:DDG';
# ABSTRACT: List commands and usage
$App::DuckPAN::Cmd::Env::Cmd::Help::VERSION = '0.171';
use Moo;
with qw( App::DuckPAN::Cmd::Env::Cmd );

use MooX::Options protect_argv => 0;

sub run {
    my ( $self ) = @_;
    $self->env->help();
}

1;

__END__

=pod

=head1 NAME

App::DuckPAN::Cmd::Env::Cmd::Help - List commands and usage

=head1 VERSION

version 0.171

=head1 AUTHOR

Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by DuckDuckGo, Inc. L<https://duckduckgo.com/>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
